# Documentação

### Planos de execução:






















<!-- A lista abaixo será gerada automaticamente -->
- [101 feature plan](pr/101_feature_plan.md)
- [104 feature plan](pr/104_feature_plan.md)
- [106 feature plan](pr/106_feature_plan.md)
- [108 feature plan](pr/108_feature_plan.md)
- [110 feature plan](pr/110_feature_plan.md)
- [112 feature plan](pr/112_feature_plan.md)
- [114 feature plan](pr/114_feature_plan.md)
- [117 feature plan](pr/117_feature_plan.md)
- [119 feature plan](pr/119_feature_plan.md)
- [121 feature plan](pr/121_feature_plan.md)
- [123 feature plan](pr/123_feature_plan.md)
- [125 feature plan](pr/125_feature_plan.md)
- [127 feature plan](pr/127_feature_plan.md)
- [129 feature plan](pr/129_feature_plan.md)
- [157 feature plan](pr/157_feature_plan.md)
- [87 feature plan](pr/87_feature_plan.md)
- [89 feature plan](pr/89_feature_plan.md)
- [91 feature plan](pr/91_feature_plan.md)
- [94 feature plan](pr/94_feature_plan.md)
- [97 feature plan](pr/97_feature_plan.md)
